//===========================================================================
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//============================================================================

/* MainController */

#import <Cocoa/Cocoa.h>
#include "StdAfx.h"
#include "Platform.h"
#include "EnumPVRDrives.h"
#include "DishPvr.h"
#include "DishPVR50X.h"
#include "DishPVR522.h"
#include "DishPVR622.h"
#include "DishPVR721.h"
#include "DishPVRFile.h"
#include "ExtractProgram.h"
#include "WHICHSTREAMS.H"
#include "LOGFILE.H"


enum {
	MSG_PVR_NO_DRIVES,
	MSG_NO_INSTANCE_PVR,
	MSG_POSSIBLE_ENCRYPTION,
	MSG_CANCELED_EXT,
	MSG_FAILED_EXT,
	MSG_OPEN_FOLDER,
	MSG_BETA_TIME_EXP
};

@interface MainController : NSObject
{
		IBOutlet id m_ProgressBar;
		IBOutlet id m_ExtractBtn;
		IBOutlet id m_CancelBtn;
		IBOutlet id m_DrvSelCombo;
		IBOutlet id m_DrivePict;
		IBOutlet id m_ProgramList;
		IBOutlet id m_ChannelID;
		IBOutlet id m_ChannelNum;
		IBOutlet id m_ProgDesc;
		IBOutlet id m_FileName;
		IBOutlet id m_FrameTime;
		
		IBOutlet id m_Preferences;
		
		
		EnumPVRDrives	*m_DriveEnum;
		DishPvr			*m_pvr;
		int				m_CurSelectedDrive;
		int				m_NumPrograms;
		int				m_CurSelected;
		char			m_VideoInfoStr[128];
		char			m_AudioInfoStr[128];
		char			m_BytesInfoStr[128];
		char			m_FrameTimeStr[128];
		char			m_ProcessRate[64];
		char			m_TimeRemaining[64];
		bool			m_ExtractingMode;
		char			m_CurProgramDesc[512];
		int				m_CurProgramCh;
		char			m_CurProgramChName[32];
		int				m_TicCount;
		char			m_OutputFilename[256];
		LogFile			*m_log;
		NSIndexSet		*m_Selected;
		ExtractProgram  *m_ext;
		NSTimer			*m_Timer;
		int				m_IsInited;
}

- (void)awakeFromNib;
- (void)OnSelectChangeDrive;
- (void)OnSysClose;
- (IBAction)OnQuit:(id)sender;
- (IBAction)OnDriveSelect:(id)sender;
- (int)MessageAlert: (int)msg;
- (IBAction)OnExtractBtn:(id)sender;
- (IBAction)OnCancelBtn:(id)sender;
- (IBAction)OnPreferences:(id)sender;
- (id)tableView:(NSTableView *)aTableView objectValueForTableColumn:(NSTableColumn *)aTableColumn row:(int)rowIndex;
- (int)numberOfRowsInTableView:(NSTableView *)aTableView;
- (void)OnNewSelection;
- (void)OnTimer:(NSTimer*)theTimer;
- (void)tableViewSelectionDidChange:(NSNotification *)aNotification;

@end

